@@ -1,7 +1,3 @@
-#' @include ggthemes-package.R
-#' @include ggthemes-data.R
-NULL
-
 #' Theme inspired by fivethirtyeight.com plots
 #'
 #' Theme inspired by the plots on
@@ -12,12 +8,13 @@ NULL
 #' @export
 #' @example inst/examples/ex-theme_fivethirtyeight.R
 theme_fivethirtyeight <- function(base_size = 12, base_family = "sans") {
+  colors <- deframe(ggthemes::ggthemes_data[["fivethirtyeight"]])
   (theme_foundation(base_size = base_size, base_family = base_family)
    + theme(
      line = element_line(colour = "black"),
-     rect = element_rect(fill = ggthemes_data$fivethirtyeight["ltgray"],
+     rect = element_rect(fill = colors["Light Gray"],
                          linetype = 0, colour = NA),
-     text = element_text(colour = ggthemes_data$fivethirtyeight["dkgray"]),
+     text = element_text(colour = colors["Dark Gray"]),
      axis.title = element_blank(),
      axis.text = element_text(),
      axis.ticks = element_blank(),
@@ -28,9 +25,9 @@ theme_fivethirtyeight <- function(base_size = 12, base_family = "sans") {
      legend.box = "vertical",
      panel.grid = element_line(colour = NULL),
      panel.grid.major =
-       element_line(colour = ggthemes_data$fivethirtyeight["medgray"]),
+       element_line(colour = colors["Medium Gray"]),
      panel.grid.minor = element_blank(),
-     # unfortunately, can't mimic subtitles
+     # unfortunately, can't mimic subtitles TODO!
      plot.title = element_text(hjust = 0, size = rel(1.5), face = "bold"),
      plot.margin = unit(c(1, 1, 1, 1), "lines"),
      strip.background = element_rect()))
@@ -38,17 +35,19 @@ theme_fivethirtyeight <- function(base_size = 12, base_family = "sans") {
 
 #' fivethirtyeight.com color palette
 #'
-#' The standard three-color fivethirtyeight.com palette for line plots is
+#' The standard three-color fivethirtyeight.com palette for line plots comprises
 #' blue, red, and green.
 #'
 #' @family colour fivethirtyeight
 #' @export
 #' @example inst/examples/ex-fivethirtyeight_pal.R
 fivethirtyeight_pal <- function() {
-  function(n) {
-    colors <- ggthemes_data$fivethirtyeight[c("blue", "red", "green")]
-    unname(colors[seq_len(n)])
-  }
+  colors <- deframe(ggthemes::ggthemes_data[["fivethirtyeight"]])
+  values <- unname(colors[c("Blue", "Red", "Green")])
+  max_n <- length(values)
+  f <- manual_pal(values)
+  attr(f, "max_n") <- max_n
+  f
 }
 
 #' fivethirtyeight.com color scales
