@@ -2,6 +2,8 @@
 #'
 #' Theme based on the plots in \emph{The Wall Street Journal}.
 #'
+#' This theme should be used with \code{\link{scale_color_wsj}}.
+#'
 #' @references
 #'
 #' \url{https://twitter.com/WSJGraphics}
@@ -10,8 +12,7 @@
 #'
 #' @inheritParams ggplot2::theme_grey
 #' @param color The background color of plot. One of \code{'brown',
-#' 'gray', 'green', 'blue'}, the names of values in
-#' \code{ggthemes_data$wsj$bg}.
+#' 'gray', 'green', 'blue'}.
 #' @param title_family Plot title font family.
 #' @family themes wsj
 #' @example inst/examples/ex-theme_wsj.R
@@ -20,8 +21,8 @@ theme_wsj <- function(base_size = 12,
                       color = "brown",
                       base_family = "sans",
                       title_family = "mono") {
-  colorhex <- ggthemes_data$wsj$bg[color]
-  (theme_foundation(base_size = base_size, base_family = base_family) +
+  colorhex <- ggthemes::ggthemes_data$wsj$bg[color]
+  theme_foundation(base_size = base_size, base_family = base_family) +
     theme(line = element_line(linetype = 1, colour = "black"),
           rect = element_rect(fill = colorhex, linetype = 0, colour = NA),
           text = element_text(colour = "black"),
@@ -46,7 +47,7 @@ theme_wsj <- function(base_size = 12,
           panel.grid.minor = element_blank(),
           plot.title = element_text(hjust = 0, face = "bold"),
           plot.margin = unit(c(1, 1, 1, 1), "lines"),
-          strip.background = element_rect()))
+          strip.background = element_rect())
 }
 
 #' Wall Street Journal color palette (discrete)
@@ -75,15 +76,19 @@ theme_wsj <- function(base_size = 12,
 #'   Examples: \url{https://twitpic.com/9gfg5q}.}
 #' }
 #'
-#' @param palette \code{character} The color palette to use. This
-#' must be a name in
-#' \code{\link[=ggthemes_data]{ggthemes_data$wsj$palettes}}.
+#' @param palette \code{character} The color palette to use: .
+#' \Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$wsj$palettes))}
 #'
 #' @family colour wsj
 #' @export
 wsj_pal <- function(palette = "colors6") {
-  if (palette %in% names(ggthemes_data$wsj$palettes)) {
-    manual_pal(unname(ggthemes_data$wsj$palettes[[palette]]))
+  palettes <- ggthemes::ggthemes_data[["wsj"]][["palettes"]]
+  if (palette %in% names(palettes)) {
+    colors <- palettes[[palette]][["value"]]
+    max_n <- length(colors)
+    f <- manual_pal(unname(colors))
+    attr(f, "max_n") <- max_n
+    f
   } else {
     stop(sprintf("palette %s not a valid palette.", palette))
   }
@@ -91,9 +96,8 @@ wsj_pal <- function(palette = "colors6") {
 
 #' Wall Street Journal color and fill scales
 #'
-#' Colour and fill scales which use the palettes in
-#' \code{\link{wsj_pal}} and are meant for use with
-#' \code{\link{theme_wsj}}.
+#' Colour and fill scales which use the palettes in \code{\link{wsj_pal}}.
+#' These scales should be used with \code{\link{theme_wsj}}.
 #'
 #' @inheritParams ggplot2::scale_colour_hue
 #' @inheritParams wsj_pal
